//
//  PSMWebFile.h
//  Pandora
//
//  Created by John Pannell on 5/25/06.
//  Copyright 2006 Positive Spin Media. All rights reserved.
//

/*
 Lightweight representation of a scraped file that can be passed across the wire from the spider to the application.
 */

#import <Cocoa/Cocoa.h>


@interface PSMWebFile : NSObject {
    // content
    int             _resourceID;        // unique ID number - for logging
    NSString        *_sourceURL;
    NSString        *_parentWebPage;
    long long       _actualContentLength;
    NSString        *_MIMEType;
    NSImage         *_thumbnail;
    
    // size info
    int             _pixelsWide;
    int             _pixelsHigh;
    
    // location on disk
    NSString        *_storagePath;
    NSData          *_aliasData;
}

// creation/destruction
- (id)initWithResourceID:(int)value;        // creation from spider
- (id)initWithSourceURL:(NSString *)url;    // creation from paste
- (void)dealloc;

// accessors
- (int)resourceID;
- (void)setResourceID:(int)value;
- (NSString *)sourceURL;
- (void)setSourceURL:(NSString *)string;
- (NSString *)parentWebPage;
- (void)setParentWebPage:(NSString *)string;
- (NSString *)MIMEType;
- (void)setMIMEType:(NSString *)string;
- (long long)actualContentLength;
- (void)setActualContentLength:(long long)value;
- (NSImage *)thumbnail;
- (void)setThumbnail:(NSImage *)image;
- (NSString *)storagePath;
- (void)setStoragePath:(NSString *)path;
- (NSData *)aliasData;
- (void)setAliasData:(NSData *)data;

// archiving
- (id)initWithCoder:(NSCoder *)aDecoder;
- (void)encodeWithCoder:(NSCoder *)aCoder;
- (id)replacementObjectForPortCoder:(NSPortCoder *)aCoder;

// load file via copy/paste
- (void)loadFileData:(id)sender;

// C functions
CGImageRef PSMCreateWebFileThumbnailFromImageSource(CFURLRef url);



@end
